@@ -18,12 +18,12 @@
 
 DFM_MOUNT_USE_NS
 
-static constexpr char kDaemonService[] { "com.deepin.filemanager.daemon" };
-static constexpr char kDaemonPath[] { "/com/deepin/filemanager/daemon" };
+static constexpr char kDaemonService[] { "org.deepin.Filemanager.MountControl" };
+static constexpr char kDaemonPath[] { "/org/deepin/Filemanager" };
 static constexpr char kDaemonIntro[] { "org.freedesktop.DBus.Introspectable" };
 static constexpr char kDaemonIntroMethod[] { "Introspect" };
-static constexpr char kMountControlPath[] { "/com/deepin/filemanager/daemon/MountControl" };
-static constexpr char kMountControlIFace[] { "com.deepin.filemanager.daemon.MountControl" };
+static constexpr char kMountControlPath[] { "/org/deepin/Filemanager/MountControl" };
+static constexpr char kMountControlIFace[] { "org.deepin.Filemanager.MountControl" };
 static constexpr char kMountControlMount[] { "Mount" };
 static constexpr char kMountControlUnmount[] { "Unmount" };
 
@@ -37,6 +37,7 @@ static constexpr char kLoginDomain[] { "domain" };
 static constexpr char kLoginPasswd[] { "passwd" };
 static constexpr char kLoginTimeout[] { "timeout" };
 static constexpr char kMountFsType[] { "fsType" };
+static constexpr char kSmbConfigPath[] { "/etc/samba/smb.conf" };
 
 static constexpr char kDaemonMountRetKeyMpt[] { "mountPoint" };
 static constexpr char kDaemonMountRetKeyErrno[] { "errno" };
@@ -73,10 +74,28 @@ bool DNetworkMounter::isDaemonMountEnable()
     if (!systemBusIFace->isServiceRegistered(kDaemonService))
         return false;
 
-    QDBusInterface daemonIface(kDaemonService, kDaemonPath, kDaemonIntro,
-                               QDBusConnection::systemBus());
-    QDBusReply<QString> reply = daemonIface.call(kDaemonIntroMethod);
-    return reply.value().contains("<node name=\"MountControl\"/>");
+    // check if MountControl interface exists
+    QDBusInterface daemonIntroIface(kDaemonService, kDaemonPath, kDaemonIntro,
+                                    QDBusConnection::systemBus());
+    QDBusReply<QString> reply = daemonIntroIface.call(kDaemonIntroMethod);
+    if (reply.value().contains(R"(<node name="MountControl"/>)")) {
+        // check if "SupportedFileSystems" method exists
+        QDBusInterface introIface(kDaemonService,
+                                  kMountControlPath,
+                                  kDaemonIntro,
+                                  QDBusConnection::systemBus());
+        QDBusReply<QString> ifaceDesc = introIface.call(kDaemonIntroMethod);
+        if (!ifaceDesc.value().contains(R"(<method name="SupportedFileSystems">)"))
+            return true;
+
+        QDBusInterface mountIface(kDaemonService,
+                                  kMountControlPath,
+                                  kMountControlIFace,
+                                  QDBusConnection::systemBus());
+        QDBusReply<QStringList> supported = mountIface.call("SupportedFileSystems");
+        return supported.value().contains("cifs");
+    }
+    return false;
 }
 
 QList<QVariantMap> DNetworkMounter::loginPasswd(const QString &address)
@@ -219,9 +238,11 @@ void DNetworkMounter::mountByDaemon(const QString &address, GetMountPassInfo get
                                     DeviceOperateCallbackWithMessage mountResult, int secs)
 {
     auto requestLoginInfo = [address, getPassInfo] {
-        if (getPassInfo)
+        if (getPassInfo) {
+            QSettings setting(kSmbConfigPath, QSettings::IniFormat);
             return getPassInfo(QObject::tr("need authorization to access %1").arg(address),
-                               Utils::currentUser(), "WORKGROUP");
+                               Utils::currentUser(), setting.value("global/workgroup", "WORKGROUP").toString());
+        }
         return MountPassInfo();
     };
     auto checkThread = [] {
